<?php

ini_set('max_execution_time', 300); //300 seconds = 5 minutes

require_once('Slim/Slim.php');
require_once('includes/_dbconfig.php');
require_once('mailer/PHPMailerAutoload.php');

date_default_timezone_set('Africa/Nairobi');

\Slim\Slim::registerAutoloader();

$app = new \Slim\Slim();

$app->get('/survey/send/', 'sendSurvey');
$app->post('/survey/company/', 'addCompany');
$app->put('/survey/company/:id', 'updateCompany');
$app->delete('/survey/company/:id', 'deleteCompany');
$app->get('/survey/all/', 'getSurveys');
$app->delete('/survey/survey/:id', 'deleteSurvey');
$app->get('/survey/companies/', 'getCompanies');

$app->run();




/**
 * Function Name: deleteSurvey
 *
 * Deletes a single survey
 *
 * @param (number) (id) this is the id of the survey to be deleted
 * @return (number) (rows) the number of db rows deleted
 */
function deleteSurvey($id) {	
	
	$sql = "DELETE FROM surveys WHERE id=:id";

	try {
		$db = getConnection();
		$stmt = $db->prepare($sql);
		$stmt->bindParam("id", $id);		
		$stmt->execute();
		$rows = $stmt->rowCount();	
		$db = null;
		
		if($rows > 0){
		    $data = array('success' => true, 'message' => 'Survey successfully deleted');
			echo json_encode($data);
		}else{
			$data = array('success' => false, 'message' => 'Sorry survey NOT deleted');
			echo json_encode($data);
		}
		
	} catch(PDOException $e) {		
		$data = array('success' => false, 
					  'message' => $e->getMessage(), 
					  'code' => $e->getCode(),
					  'one_line' => $e->getLine());
		echo json_encode($data);
	}
	
}





/**
 * Function Name: deleteCompany
 *
 * Deletes a single company
 *
 * @param (number) (id) this is the id of the company to be deleted
 * @return (number) (rows) the number of db rows deleted
 */
function deleteCompany($id) {	
	
	$sql = "DELETE FROM companies WHERE id=:id";

	try {
		$db = getConnection();
		$stmt = $db->prepare($sql);
		$stmt->bindParam("id", $id);		
		$stmt->execute();
		$rows = $stmt->rowCount();	
		$db = null;
		
		if($rows > 0){
		    $data = array('success' => true, 'message' => 'Company successfully deleted');
			echo json_encode($data);
		}else{
			$data = array('success' => false, 'message' => 'Sorry company NOT deleted');
			echo json_encode($data);
		}
		
	} catch(PDOException $e) {		
		$data = array('success' => false, 
					  'message' => $e->getMessage(), 
					  'code' => $e->getCode(),
					  'one_line' => $e->getLine());
		echo json_encode($data);
	}
	
}






/**
 * Function Name: getCompanies
 *
 * Returns the full list of companies
 *
 * @param (array) ([companies details]) the companies details
 * @return (number) ($rows) the number of rows added
 *
 */
function getCompanies() {	
	
	$sql = "SELECT id,company_name,industry,email_address,take_survey FROM companies ORDER BY id";
	    
	    try {	
	    			    	
	    	$db = getConnection();
			$stmt = $db->prepare($sql);
			$rows = $stmt->execute();
			$companies = $stmt->fetchAll(PDO::FETCH_OBJ);						

			$db = null;

			$data = array('success' => true, 'companies' => $companies);
			echo json_encode($data);
	    
	    } catch(PDOException $e) {		
		     
		    $data = array('success' => false, 'message' => $e->getMessage());
			echo json_encode($data);
	    }		   
	
}





/**
 * Function Name: sendSurvey
 *
 * Returns the full list of companies that needs a survey
 *
 * @param (array) ([companies details]) the companies details
 * @return (number) ($rows) the number of rows added
 *
 */
function sendSurvey() {	
	
	$sql = "SELECT id,company_name,email_address FROM companies WHERE take_survey = 1 ORDER BY id";
	    
	    try {	
	    			    	
	    	$db = getConnection();
			$stmt = $db->prepare($sql);
			$rows = $stmt->execute();
			$companies = $stmt->fetchAll(PDO::FETCH_OBJ);						

			$db = null;

			if(count($companies) > 0){

				send_survey($companies);

				$data = array('success' => true, 'companies' => $companies);
				echo json_encode($data);

			}else{
				$data = array('success' => false, 'message' => 'Sorry there were no companies to send surveys to');
				echo json_encode($data);
			}
			
	    
	    } catch(PDOException $e) {		
		     
		    $data = array('success' => false, 'message' => $e->getMessage());
			echo json_encode($data);
	    }		   
	
}




function send_survey($companies){

	foreach ($companies as $company) {
	    
	    $contact = new stdClass();
	    $contact->company_id = $company->id;
		$contact->company_name = $company->company_name;		
		$contact->email_address = $company->email_address;

		send_email($contact);
	}	

}




/**
 * Function Name: getSurveys
 *
 * Returns the full list of surveys
 *
 * @param (array) ([surveys details]) the surveys details
 * @return (number) ($rows) the number of rows added
 *
 */
function getSurveys() {	
	
	$sql = "SELECT s.id, company_id, c.company_name, question_one, question_two, question_three, question_four, quality_of_our_proposals, costs, project_execution, communication, creativity_and_innovation, customer_support FROM survey as s INNER JOIN companies as c ON s.company_id = c.id ORDER BY s.id";
	    
	    try {	
	    			    	
	    	$db = getConnection();
			$stmt = $db->prepare($sql);
			$rows = $stmt->execute();
			$surveys = $stmt->fetchAll(PDO::FETCH_OBJ);						

			$db = null;

			$data = array('success' => true, 'surveys' => $surveys);
			echo json_encode($data);
	    
	    } catch(PDOException $e) {		
		     
		    $data = array('success' => false, 'message' => $e->getMessage());
			echo json_encode($data);
	    }		   
	
}





/**
 * Function Name: addCompany
 *
 * Adds a new company
 *
 * @param (array) ([company details]) the company details
 * @return (number) ($rows) the number of rows added
 *
 */
function addCompany() {
	
	$request = \Slim\Slim::getInstance()->request();
	
	$company = json_decode($request->getBody());//true makes the result as an array object

	$sql = "INSERT INTO companies (company_name, email_address, industry, take_survey) VALUES (:company_name, :email_address, :industry, :take_survey)";
	    
	    try {	    	

	    	$company_name = $company->company_name;	  
	    	$email_address = $company->email_address;
	    	$industry = $company->industry;
	    	$take_survey = $company->take_survey;
	    	$take_survey = intval($take_survey);

	    	$company_name = cleanField($company_name);

	    	$db = getConnection();
			$stmt = $db->prepare($sql);			
			
			$stmt->bindParam("company_name", $company_name);			
			$stmt->bindParam("email_address", $email_address);
			$stmt->bindParam("industry", $industry);
			$stmt->bindParam("take_survey", $take_survey);		
			
			$rows = $stmt->execute();			

			$db = null;

			if($rows > 0){
				
				$message = 'Company has been added';
				$data = array('success' => true, 'message' => $message);
				echo json_encode($data);					    
			    
			}else{
		    	
		    	$data = array('success' => false, 'message' => 'Sorry unable to process your data');
				echo json_encode($data);
		    }
	    
		    
	    
	    } catch(PDOException $e) {		
		     
		    $data = array('success' => false, 'message' => $e->getMessage());
			echo json_encode($data);
	    }		   
	
}






/**
 * Function Name: updateCompany
 *
 * Update company
 *
 * @param (array) ([company details]) the company details
 * @return (number) ($rows) the number of rows added
 *
 */
function updateCompany($id) {
	
	$request = \Slim\Slim::getInstance()->request();
	
	$company = json_decode($request->getBody());//true makes the result as an array object	

	$sql = "UPDATE companies SET company_name =:company_name, email_address =:email_address, industry =:industry, take_survey =:take_survey WHERE id =:id";
	    
	    try {	    	

	    	$company_name = $company->company_name;	  
	    	$email_address = $company->email_address;
	    	$industry = $company->industry;
	    	$take_survey = $company->take_survey;

	    	$company_name = cleanField($company_name);

	    	$db = getConnection();
			$stmt = $db->prepare($sql);			
			
			$stmt->bindParam("company_name", $company_name);			
			$stmt->bindParam("email_address", $email_address);
			$stmt->bindParam("industry", $industry);
			$stmt->bindParam("take_survey", $take_survey);	
			$stmt->bindParam(":id",$id);
			
			$rows = $stmt->execute();			

			$db = null;

			if($rows > 0){
				
				$message = 'Company has been updated';
				$data = array('success' => true, 'message' => $message);
				echo json_encode($data);					    
			    
			}else{
		    	
		    	$data = array('success' => false, 'message' => 'Sorry unable to process your data');
				echo json_encode($data);
		    }
	    
		    
	    
	    } catch(PDOException $e) {		
		     
		    $data = array('success' => false, 'message' => $e->getMessage());
			echo json_encode($data);
	    }		   
	
}



function get_include_contents($filename, $variablesToMakeLocal) {

    extract($variablesToMakeLocal);

    if (is_file($filename)) {
        ob_start();
        include $filename;
        return ob_get_clean();
    }
    
    return false;
} 



/**
 * Function Name: send_email
 *
 * send an email to a lead
 *
 * @param (text) ($contact_name) name of gamer
 * @param (email) ($email_address) gamer email address
 *
 */
function send_email($contact){

	$data = array('company_name' => $contact->company_name, 'company_id' => $contact->company_id);

	$x = 'Hi '.$contact->company_name. ', Please fill the form below . Thank you. iZone Africa';
	
	$mail_sent = false;

	//Create a new PHPMailer instance
	$mail = new PHPMailer;

	//Tell PHPMailer to use SMTP
	$mail->isSMTP();

	//Enable SMTP debugging
	// 0 = off (for production use)
	// 1 = client messages
	// 2 = client and server messages
	$mail->SMTPDebug = 0;

	//Ask for HTML-friendly debug output
	$mail->Debugoutput = 'html';

	//Set the hostname of the mail server
	$mail->Host = 'smtp.gmail.com';

	//Set the SMTP port number - 587 for authenticated TLS, a.k.a. RFC4409 SMTP submission
	$mail->Port = 587;

	//Set the encryption system to use - ssl (deprecated) or tls
	$mail->SMTPSecure = 'tls';

	//Whether to use SMTP authentication
	$mail->SMTPAuth = true;	

	//Username to use for SMTP authentication - use full email address for gmail
	$mail->Username = SMTP_EMAIL_ADDRESS;

	//Password to use for SMTP authentication
	$mail->Password = SMTP_EMAIL_ADDRESS_PASSWORD;

	//Set who the message is to be sent from
	$mail->setFrom(SMTP_EMAIL_ADDRESS, SMTP_EMAIL_NAME);

	//Set an alternative reply-to address
	$mail->addReplyTo(SMTP_EMAIL_ADDRESS, SMTP_EMAIL_NAME);

	//Set who the message is to be sent to
	$mail->addAddress($contact->email_address, $contact->company_name);

	//Set the subject line
	$mail->Subject = EMAIL_SUBJECT . ' - ' . $contact->company_name;

	//Path to image file (use full path)
 
	$filepath= 'survey.jpg';
	 
	//File token ID, use unique interger.
	 
	$filecid = 1001;
	 
	//File name which will be in the mail, overrides default filename.
	 
	$filename= 'survey.jpg';
	 
	//Encoding
	 
	$encoding = 'base64';
	 
	//File type MIME
	 
	$filemime = 'image/jpeg';
	 
	//EMBED IT
	 
	$mail->AddEmbeddedImage($filepath, $filecid, $filename, $encoding, $filemime);	

	$mail->IsHTML(true);    // set email format to HTML

	//Read an HTML message body from an external file, convert referenced images to embedded,
	
	//$mail->msgHTML(file_get_contents('lead.html'), dirname(__FILE__));
	$mail->Body = get_include_contents('email.php', $data); // HTML -> PHP!
	
	//Replace the plain text body with one created manually
	$mail->AltBody = $x;
	
	//Attach an image file
	//$mail->addAttachment('pdfs/TrailBlazer-Brochure.pdf');

	//send the message, check for errors
	if ($mail->send()) {
	    //echo "Mailer Error: " . $mail->ErrorInfo;
	    $mail_sent =true;
	}else {
	    echo "Mailer Error: " . $mail->ErrorInfo;
	}

	return $mail_sent;


}






function checkEmail($str){
	return preg_match("/^[\.A-z0-9_\-\+]+[@][A-z0-9_\-]+([.][A-z0-9_\-]+)+[A-z]{1,4}$/", $str);
}



function cleanField($text){
	
	$name = preg_replace("/[^a-zA-Z0-9\/_|+,<>\[\]() .-]/", '', $text);//remove special characters
	$name = preg_replace("/[\"\']/", '', $name); //remove any quotes

	return $name;
}



?>
