define(['./module', 'jquery', ], function (controllers, jQuery) {
    'use strict';
    
    controllers.controller("CompaniesController", ["$scope", "$state", "settings", "modals", "$q", "$rootScope", "DTOptionsBuilder", "DTColumnDefBuilder", "properties", function($scope, $state, settings, modals, $q, $rootScope, DTOptionsBuilder, DTColumnDefBuilder, properties) {
	   
	    // set sidebar closed and body solid layout mode
	    $rootScope.settings.layout.pageContentWhite = true;
	    $rootScope.settings.layout.pageBodySolid = false;
	    $rootScope.settings.layout.pageSidebarClosed = false;

		$scope.companies = properties.getCompanies();

	    var z = settings.loadCompanies();

	    z.then(function(data) {
	     
	        if(data == true){
	           $scope.companies = properties.getCompanies();
	        }

	    },function(error) {
	        console.error(error);
	    }); 

	    var getCompanies = function(){

	         var defer = $q.defer();	         

	         var promise = settings.getCompanies();

	         promise.then(function(data) {
	              
	              var response = data.data;

	              if(response.success){
	                $scope.companies = response.companies;
	                defer.resolve(response.companies);
	              }else{
	                console.error('Server error: '+response.message);
	              }	              

	         },function(error) {
	              console.error(error);
	         });        

	        return defer.promise;
	    };     

	    $scope.dtInstance = {};  

	    DTOptionsBuilder.newOptions(function(){
	      return this.withOption('lengthMenu', [20, 50, 100, 150, 200, 500])
	    });

	    $scope.dtOptions = DTOptionsBuilder.fromFnPromise(function() {
	        return getCompanies();
	    }).withDOM('Bfrtip')
	      .withPaginationType('full_numbers')
	      .withDisplayLength(20)
	      .withOption('language', {        
	        zeroRecords: 'Loading Data...'
	      })
	      .withButtons([
	        {
	            extend: 'csv',
	            text: 'Export to CSV',
	            exportOptions: {
	                columns: [0, 1, 2, 3, 4]
	            }
	        }
	      ]);	    

	    $scope.dtColumnDefs = [
	        DTColumnDefBuilder.newColumnDef(0),
	        DTColumnDefBuilder.newColumnDef(1),
	        DTColumnDefBuilder.newColumnDef(2),	        
	        DTColumnDefBuilder.newColumnDef(3),
	        DTColumnDefBuilder.newColumnDef(4),
	        DTColumnDefBuilder.newColumnDef(5).notSortable().withOption('className', 'action-width')
	    ];
	    


	    $scope.newCompany = function(){

	        modals.NewCompanyModal();       

	    };

	    $scope.editCompany = function(company){    	
	    	
	        modals.EditCompanyModal(company);       

	    };

	    $scope.sendSurvey = function(){
	    	
	    	var promise = settings.sendSurvey();

	         promise.then(function(data) {

	              var response = data.data;

	              if(response.success){
	                modals.showNoticeModal(response.companies.length +' Surveys sent out', 'info');
	              }else{
	                modals.showNoticeModal(response.message, 'info');
	              }	              

	         },function(error) {
	              console.error(error);
	         }); 

	    };

	    $scope.showCompany = function(company){
	        modals.ShowCompanyModal(company);
	    };


	    $scope.deleteCompany = function (company_id) {	    	

	        var promise = modals.showConfirmModal('Are you sure you want to delete this company?');

	        promise.then(function(response){
	              
	          if(response){

	            settings.deleteCompany(company_id);

	            modals.showNoticeModal('Company successfully deleted', 'info');  

	          }

	        });	        
	      
	    };


	    	     
	  }//End of function()

	]);
});
