define(['./module', 'jquery', ], function (controllers, jQuery) {
    'use strict';
    
    controllers.controller("SurveysController", ["$scope", "$state", "settings", "modals", "$q", "$rootScope", "DTOptionsBuilder", "DTColumnDefBuilder", "properties", function($scope, $state, settings, modals, $q, $rootScope, DTOptionsBuilder, DTColumnDefBuilder, properties) {
	   
	    // set sidebar closed and body solid layout mode
	    $rootScope.settings.layout.pageContentWhite = true;
	    $rootScope.settings.layout.pageBodySolid = false;
	    $rootScope.settings.layout.pageSidebarClosed = false;

		$scope.surveys = properties.getSurveys();

	    var z = settings.loadSurveys();

	    z.then(function(data) {
	     
	        if(data == true){
	           $scope.surveys = properties.getSurveys();
	        }

	    },function(error) {
	        console.log(error);
	    }); 

	    var getSurveys = function(){

	         var defer = $q.defer();	         

	         var promise = settings.getSurveys();

	         promise.then(function(data) {
	              
	              var response = data.data;

	              if(response.success){
	                $scope.surveys = response.surveys;
	                defer.resolve(response.surveys);
	              }else{
	                console.log('Server error: '+response.message);
	              }	              

	         },function(error) {
	              console.log(error);
	         });        

	        return defer.promise;
	    };     

	    $scope.dtInstance = {};  

	    DTOptionsBuilder.newOptions(function(){
	      return this.withOption('lengthMenu', [20, 50, 100, 150, 200, 500])
	    });

	    $scope.dtOptions = DTOptionsBuilder.fromFnPromise(function() {
	        return getSurveys();
	    }).withDOM('Bfrtip')
	      .withPaginationType('full_numbers')
	      .withDisplayLength(20)
	      .withOption('language', {        
	        zeroRecords: 'Loading Data...'
	      })
	      .withButtons([
	        {
	            extend: 'csv',
	            text: 'Export to CSV',
	            exportOptions: {
	                columns: [0, 1, 2, 3, 4]
	            }
	        }
	      ]);	    

	    $scope.dtColumnDefs = [
	        DTColumnDefBuilder.newColumnDef(0),
	        DTColumnDefBuilder.newColumnDef(1),
	        DTColumnDefBuilder.newColumnDef(2),	        
	        DTColumnDefBuilder.newColumnDef(3),
	        DTColumnDefBuilder.newColumnDef(4),
	        DTColumnDefBuilder.newColumnDef(5).notSortable().withOption('className', 'action-width')
	    ];
	    


	    $scope.showSurvey = function(survey){

	        modals.ShowSurveyModal(survey);       

	    };


	    $scope.deleteSurvey = function (survey_id) {

	        var promise = modals.showConfirmModal('Are you sure you want to delete this survey?');

	        promise.then(function(response) {
	              
	          if(response){

	            settings.deleteSurvey(survey_id);

	            modals.showNoticeModal('Survey successfully deleted', 'info');  

	          }

	        });	        
	      
	    };


	    	     
	  }//End of function()

	]);
});
