define(['./module', 'jquery', 'moment', 'daterangepicker'], function (directives, jQuery, moment, daterangepicker) {
    'use strict';

    directives.directive('daterange', ['$rootScope', '$timeout', 'properties', function ($rootScope, $timeout, properties) {        
        
        return {
            restrict: 'EA',
            scope: { resetSummary: '&callback' },
            link: function (scope, elem) {

                $timeout(function(){
                     
                      var handleDateRangePickers = function () {

                          if (!jQuery().daterangepicker) {
                              return;
                          }

                          $('#defaultrange').daterangepicker({
                                  opens: (App.isRTL() ? 'left' : 'right'),
                                  format: 'MM/DD/YYYY',
                                  separator: ' to ',
                                  startDate: moment().subtract(29, 'days'),
                                  endDate: moment(),
                                  minDate: '01/01/2012',
                                  maxDate: '12/31/2018',
                              },
                              function (start, end) {
                                  $('#defaultrange input').val(start.format('MMMM D, YYYY') + ' - ' + end.format('MMMM D, YYYY'));
                              }
                          );        

                          $('#defaultrange_modal').daterangepicker({
                                  opens: (App.isRTL() ? 'left' : 'right'),
                                  format: 'MM/DD/YYYY',
                                  separator: ' to ',
                                  startDate: moment().subtract(29, 'days'),
                                  endDate: moment(),
                                  minDate: '01/01/2012',
                                  maxDate: '12/31/2018',
                              },
                              function (start, end) {
                                  $('#defaultrange_modal input').val(start.format('MMMM D, YYYY') + ' - ' + end.format('MMMM D, YYYY'));
                              }
                          );  

                          // this is very important fix when daterangepicker is used in modal. in modal when daterange picker is opened and mouse clicked anywhere bootstrap modal removes the modal-open class from the body element.
                          // so the below code will fix this issue.
                          $('#defaultrange_modal').on('click', function(){
                              if ($('#daterangepicker_modal').is(":visible") && $('body').hasClass("modal-open") == false) {
                                  $('body').addClass("modal-open");
                              }
                          });

                          $('#reportrange').daterangepicker({
                                  opens: (App.isRTL() ? 'left' : 'right'),
                                  startDate: moment().subtract(29, 'days'),
                                  endDate: moment(),
                                  minDate: '01/01/2012',
                                  maxDate: '12/31/2018',
                                  dateLimit: {
                                      days: 60
                                  },
                                  showDropdowns: true,
                                  showWeekNumbers: true,
                                  timePicker: false,
                                  timePickerIncrement: 1,
                                  timePicker12Hour: true,
                                  ranges: {
                                      'Today': [moment(), moment()],
                                      'Yesterday': [moment().subtract(1, 'days'), moment().subtract(1, 'days')],
                                      'Last 7 Days': [moment().subtract(6, 'days'), moment()],
                                      'Last 30 Days': [moment().subtract(29, 'days'), moment()],
                                      'This Month': [moment().startOf('month'), moment().endOf('month')],
                                      'Last Month': [moment().subtract(1, 'month').startOf('month'), moment().subtract(1, 'month').endOf('month')]
                                  },
                                  buttonClasses: ['btn'],
                                  applyClass: 'green',
                                  cancelClass: 'default',
                                  format: 'MM/DD/YYYY',
                                  separator: ' to ',
                                  locale: {
                                      applyLabel: 'Apply',
                                      fromLabel: 'From',
                                      toLabel: 'To',
                                      customRangeLabel: 'Custom Range',
                                      daysOfWeek: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
                                      monthNames: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'],
                                      firstDay: 1
                                  }
                              },
                              function (start, end) {
                                  $('#reportrange span').html(start.format('MMMM D, YYYY') + ' - ' + end.format('MMMM D, YYYY'));

                                  scope.start_date = start.format('MMMM D, YYYY');
                                  scope.end_date = end.format('MMMM D, YYYY');

                                  properties.setStartDate(scope.start_date);
                                  properties.setEndDate(scope.end_date);

                                  scope.resetSummary({start: scope.start_date, end: scope.end_date});
                              }
                          );
                          //Set the initial state of the picker label
                          $('#reportrange span').html(moment().subtract(29, 'days').format('MMMM D, YYYY') + ' - ' + moment().format('MMMM D, YYYY'));

                          scope.start_date = moment().subtract(29, 'days').format('MMMM D, YYYY');
                          scope.end_date = moment().format('MMMM D, YYYY');

                          properties.setStartDate(scope.start_date);
                          properties.setEndDate(scope.end_date);

                          scope.resetSummary({start: scope.start_date, end: scope.end_date});

                      }

                    handleDateRangePickers();

                });
            }

          };

    }]);	

});
